[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10723301.svg)](https://doi.org/10.5281/zenodo.10723301)

## pagn

`pagn` is a Python module to solve the equations from [Sirko and Goodman 2003](https://academic.oup.com/mnras/article/341/2/501/1105444) and [Thompson et al. 2005](https://iopscience.iop.org/article/10.1086/431923) in a way that is simple, clear and highly customisable. Our aim is to provide a code that with the correct inputs provides a fully evolved AGN disk model through parametric 1D curves for key disk parameters such as temperature and density. We expect key applications of this code to be studies of migration torques in AGN disks, simulations of compact object formation inside gas disks, and comparisons with new, more complex models of AGN disks.

`pagn` is under the GPLv3 licence. Please use `pagn` as you like but cite our work using the DOI above. 

The code is distributed under git version control at
- [github.com/DariaGangardt/pagn](https://github.com/DariaGangardt/pagn)

To install the code, use:
	
	pip install pagn

Documentation can be found [here](https://DariaGangardt.github.io/pagn), where we also provide examples for how to run the code.

The code is maintained by Daria Gangardt and [Alessandro A. Trani](https://alessandrotrani.space). Please report bugs, errors and provide suggestions using github.
Repository template provided by Davide Gerosa.

We hope that you find `pAGN` useful and that it saves you lots of time!
